==> haskell-adjunctions-4.3-21-i686.pkg.tar.xz: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.3
id: adjunctions-4.3-DdaVzHtQIdKKcIMAtenkpN
key: adjunctions-4.3-DdaVzHtQIdKKcIMAtenkpN
license: BSD3
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors
category: Data Structures, Adjunctions
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
abi: 9ec530440413038174bf66e70e3dbfbf
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/adjunctions-4.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/adjunctions-4.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/adjunctions-4.3
hs-libraries: HSadjunctions-4.3-DdaVzHtQIdKKcIMAtenkpN
depends:
    array-0.5.1.1 base-4.9.0.0 comonad-5-1roHbXsedY6KUNYFgPJLp6
    containers-0.5.7.1 contravariant-1.4-89BvpwBnlCJ6iFzBGVF7XO
    distributive-0.5.0.2-2AokE99FpE59iSGkvIRYC4
    free-4.12.4-LcxMyZIxIoo6h2gqXah9QK mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    profunctors-5.2-CUL7kUu4nBbDVNmgOaH64k
    semigroupoids-5.1-5WI5yrkqR6b5vppUpisNlN
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    void-0.7.1-BXitqvas4xpGkaFQbixoM1
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-adjunctions-4.3-23-i686.pkg.tar.xz: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.3
id: adjunctions-4.3-BfmmbR5OgFBEUx5qk17tC7
key: adjunctions-4.3-BfmmbR5OgFBEUx5qk17tC7
license: BSD3
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors
category: Data Structures, Adjunctions
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
abi: 381c6b4f5b1cbaac5daa399dbd897f99
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/adjunctions-4.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/adjunctions-4.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/adjunctions-4.3
hs-libraries: HSadjunctions-4.3-BfmmbR5OgFBEUx5qk17tC7
depends:
    array-0.5.1.1 base-4.9.0.0 comonad-5-32c0CBnUQitJOjClwXgxTu
    containers-0.5.7.1 contravariant-1.4-QSyIMKSTFU5sk4KxSecCX
    distributive-0.5.1-BXBEYSWODmEIzmEEO7ASAJ
    free-4.12.4-Aed7uNZqrKqF7XkiVApgap mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    profunctors-5.2-5RA339bRfsXIbryi2lNqpM
    semigroupoids-5.1-DzcNuJqpBH92pXLHWsg7Nu
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    void-0.7.1-7ItcNGyWY8l57cMz7KooSQ
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
